/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**
**
**
**
**
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QL2CAPSERVER_H
#define QL2CAPSERVER_H

#include <qmobilityglobal.h>

#include <QObject>

#include <qbluetoothaddress.h>
#include <qbluetooth.h>
#include <qbluetoothsocket.h>

QT_BEGIN_HEADER

QTM_BEGIN_NAMESPACE

class QL2capServerPrivate;
class QBluetoothSocket;

class Q_CONNECTIVITY_EXPORT QL2capServer : public QObject
{
    Q_OBJECT

public:
    QL2capServer(QObject *parent = 0);
    ~QL2capServer();

    void close();

    bool listen(const QBluetoothAddress &address = QBluetoothAddress(), quint16 port = 0);
    bool isListening() const;

    void setMaxPendingConnections(int numConnections);
    int maxPendingConnections() const;

    bool hasPendingConnections() const;
    QBluetoothSocket *nextPendingConnection();

    QBluetoothAddress serverAddress() const;
    quint16 serverPort() const;

    void setSecurityFlags(QBluetooth::SecurityFlags security);
    QBluetooth::SecurityFlags securityFlags() const;

signals:
    void newConnection();

protected:
    QL2capServerPrivate *d_ptr;

private:
    Q_DECLARE_PRIVATE(QL2capServer)

#ifdef QTM_SYMBIAN_BLUETOOTH
    Q_PRIVATE_SLOT(d_func(), void _q_connected())
    Q_PRIVATE_SLOT(d_func(), void _q_socketError(QBluetoothSocket::SocketError err))
    Q_PRIVATE_SLOT(d_func(), void _q_disconnected())
#endif //QTM_SYMBIAN_BLUETOOTH
    
#ifndef QT_NO_DBUS
    Q_PRIVATE_SLOT(d_func(), void _q_newConnection())
#endif

};

QTM_END_NAMESPACE

QT_END_HEADER

#endif
